pub struct Line {
pub origin: Vec3,
pub direction: Vec3,
}Expand description
An infinite line defined by a point and a direction.
Fields
origin: Vec3direction: Vec3Normalized direction.
Implementations
Sourceimpl Line
impl Line
Sourcepub fn new(origin: Vec3, direction: Vec3) -> Result<Self, HisabError>
pub fn new(origin: Vec3, direction: Vec3) -> Result<Self, HisabError>
Create a new line. Direction is normalized automatically.
Errors
Returns crate::HisabError::InvalidInput if direction is zero-length.
Sourcepub fn closest_point(&self, point: Vec3) -> Vec3
pub fn closest_point(&self, point: Vec3) -> Vec3
Closest point on this infinite line to the given point.
Sourcepub fn distance_to_point(&self, point: Vec3) -> f32
pub fn distance_to_point(&self, point: Vec3) -> f32
Distance from a point to this line.