pub struct Segment {
pub start: Vec3,
pub end: Vec3,
}Expand description
A line segment defined by start and end points.
Fields
start: Vec3end: Vec3Implementations
Sourceimpl Segment
impl Segment
Sourcepub fn direction(&self) -> Vec3
pub fn direction(&self) -> Vec3
Normalized direction from start to end.
Returns Vec3::X for degenerate (zero-length) segments.
Sourcepub fn closest_point(&self, point: Vec3) -> Vec3
pub fn closest_point(&self, point: Vec3) -> Vec3
Closest point on this segment to the given point.
Sourcepub fn distance_to_point(&self, point: Vec3) -> f32
pub fn distance_to_point(&self, point: Vec3) -> f32
Distance from a point to this segment.